@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -61,24 +61,19 @@ static BonoboObjectClass *parent_class = NULL;
 
 struct _AddressbookComponentPrivate {
 	GConfClient *gconf_client;
-	char *base_directory;
+	gchar *base_directory;
 	GList *views;
 };
 
 static void
 ensure_sources (AddressbookComponent *component)
 {
-	GSList *groups;
 	ESourceList *source_list;
-	ESourceGroup *group;
 	ESourceGroup *on_this_computer;
-	ESourceGroup *on_ldap_servers;
 	ESource *personal_source;
-	char *base_uri, *base_uri_proto;
+	gchar *base_uri, *base_uri_proto, base_uri_proto_seventh;
 	const gchar *base_dir;
 
-	on_this_computer = NULL;
-	on_ldap_servers = NULL;
 	personal_source = NULL;
 
 	if (!e_book_get_addressbooks (&source_list, NULL)) {
@@ -90,24 +85,20 @@ ensure_sources (AddressbookComponent *component)
 	base_uri = g_build_filename (base_dir, "local", NULL);
 
 	base_uri_proto = g_filename_to_uri (base_uri, NULL, NULL);
+	if (strlen (base_uri_proto) >= 7) {
+		/* compare only file:// part. If user home dir name changes we do not want to create
+		   one more group  */
+		base_uri_proto_seventh = base_uri_proto[7];
+		base_uri_proto[7] = 0;
+	} else {
+		base_uri_proto_seventh = -1;
+	}
 
-	groups = e_source_list_peek_groups (source_list);
-	if (groups) {
-		/* groups are already there, we need to search for things... */
-		GSList *g;
+	on_this_computer = e_source_list_ensure_group (source_list, _("On This Computer"), base_uri_proto, TRUE);
+	e_source_list_ensure_group (source_list, _("On LDAP Servers"), LDAP_BASE_URI, FALSE);
 
-		for (g = groups; g; g = g->next) {
-
-			group = E_SOURCE_GROUP (g->data);
-
-			/* compare only file:// part. If user home dir name changes we do not want to create
-			   one more group  */
-
-			if (!on_this_computer && !strncmp (base_uri_proto, e_source_group_peek_base_uri (group), 7))
-				on_this_computer = group;
-			else if (!on_ldap_servers && !strcmp (LDAP_BASE_URI, e_source_group_peek_base_uri (group)))
-				on_ldap_servers = group;
-		}
+	if (base_uri_proto_seventh != -1) {
+		base_uri_proto[7] = base_uri_proto_seventh;
 	}
 
 	if (on_this_computer) {
@@ -138,15 +129,11 @@ ensure_sources (AddressbookComponent *component)
 		    e_source_list_sync (source_list,NULL);
 		}
 	}
-	else {
-		/* create the local source group */
-		group = e_source_group_new (_("On This Computer"), base_uri_proto);
-		e_source_list_add_group (source_list, group, -1);
 
-		on_this_computer = group;
-	}
-
-	if (!personal_source) {
+	if (personal_source) {
+		/* ensure the source name is in current locale, not read from configuration */
+		e_source_set_name (personal_source, _("Personal"));
+	} else {
 		/* Create the default Person addressbook */
 		ESource *source = e_source_new (_("Personal"), PERSONAL_RELATIVE_URI);
 		e_source_group_add_source (on_this_computer, source, -1);
@@ -157,14 +144,7 @@ ensure_sources (AddressbookComponent *component)
 		personal_source = source;
 	}
 
-	if (!on_ldap_servers) {
-		/* Create the LDAP source group */
-		group = e_source_group_new (_("On LDAP Servers"), LDAP_BASE_URI);
-		e_source_list_add_group (source_list, group, -1);
-
-		on_ldap_servers = group;
-	}
-
+	g_object_unref (on_this_computer);
 	g_free (base_uri_proto);
 	g_free (base_uri);
 }
@@ -224,28 +204,28 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	CORBA_sequence_set_release (list, FALSE);
 
-	list->_buffer[0].id = "contact";
+	list->_buffer[0].id = (gchar *) "contact";
 	list->_buffer[0].description = _("New Contact");
-	list->_buffer[0].menuDescription = (char *) C_("New", "_Contact");
+	list->_buffer[0].menuDescription = (gchar *) C_("New", "_Contact");
 	list->_buffer[0].tooltip = _("Create a new contact");
 	list->_buffer[0].menuShortcut = 'c';
-	list->_buffer[0].iconName = "contact-new";
+	list->_buffer[0].iconName = (gchar *) "contact-new";
 	list->_buffer[0].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[1].id = "contact_list";
+	list->_buffer[1].id = (gchar *) "contact_list";
 	list->_buffer[1].description = _("New Contact List");
-	list->_buffer[1].menuDescription = (char *) C_("New", "Contact _List");
+	list->_buffer[1].menuDescription = (gchar *) C_("New", "Contact _List");
 	list->_buffer[1].tooltip = _("Create a new contact list");
 	list->_buffer[1].menuShortcut = 'l';
-	list->_buffer[1].iconName = "stock_contact-list";
+	list->_buffer[1].iconName = (gchar *) "stock_contact-list";
 	list->_buffer[1].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[2].id = "address_book";
+	list->_buffer[2].id = (gchar *) "address_book";
 	list->_buffer[2].description = _("New Address Book");
-	list->_buffer[2].menuDescription = (char *) C_("New", "Address _Book");
+	list->_buffer[2].menuDescription = (gchar *) C_("New", "Address _Book");
 	list->_buffer[2].tooltip = _("Create a new address book");
 	list->_buffer[2].menuShortcut = '\0';
-	list->_buffer[2].iconName = "address-book-new";
+	list->_buffer[2].iconName = (gchar *) "address-book-new";
 	list->_buffer[2].type = GNOME_Evolution_CREATABLE_FOLDER;
 
 	return list;
@@ -255,7 +235,7 @@ static void
 book_loaded_cb (EBook *book, EBookStatus status, gpointer data)
 {
 	EContact *contact;
-	char *item_type_name = data;
+	gchar *item_type_name = data;
 
 	if (status != E_BOOK_ERROR_OK) {
 		/* XXX we really need a dialog here, but we don't have
@@ -287,7 +267,7 @@ impl_requestCreateItem (PortableServer_Servant servant,
 	EBook *book;
 	GConfClient *gconf_client;
 	ESourceList *source_list;
-	char *uid;
+	gchar *uid;
 
 	if (!item_type_name ||
 	    (strcmp (item_type_name, "address_book") &&
@@ -330,7 +310,7 @@ impl_requestCreateItem (PortableServer_Servant servant,
 
 static void
 impl_handleURI (PortableServer_Servant servant,
-		const char* uri,
+		const gchar * uri,
 		CORBA_Environment *ev)
 {
 	AddressbookComponent *addressbook_component = ADDRESSBOOK_COMPONENT (bonobo_object_from_servant (servant));
@@ -338,8 +318,8 @@ impl_handleURI (PortableServer_Servant servant,
 	AddressbookView *view = NULL;
 
 	GList *l;
-	char *src_uid = NULL;
-	char *contact_uid = NULL;
+	gchar *src_uid = NULL;
+	gchar *contact_uid = NULL;
 
 	priv = addressbook_component->priv;
 	l = g_list_last (priv->views);
@@ -350,9 +330,9 @@ impl_handleURI (PortableServer_Servant servant,
 
 	if (!strncmp (uri, "contacts:", 9)) {
 		EUri *euri = e_uri_new (uri);
-		const char *p;
-		char *header, *content;
-		size_t len, clen;
+		const gchar *p;
+		gchar *header, *content;
+		gsize len, clen;
 
 		p = euri->query;
 		if (p) {
@@ -363,7 +343,7 @@ impl_handleURI (PortableServer_Servant servant,
 				if (p[len] != '=')
 					break;
 
-				header = (char *) p;
+				header = (gchar *) p;
 				header[len] = '\0';
 				p += len + 1;
 
@@ -453,7 +433,6 @@ impl_finalize (GObject *object)
 	(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
-
 /* Initialization.  */
 
 static void
@@ -482,7 +461,7 @@ static void
 addressbook_component_init (AddressbookComponent *component)
 {
 	AddressbookComponentPrivate *priv;
-	static int first = TRUE;
+	static gint first = TRUE;
 
 	priv = g_new0 (AddressbookComponentPrivate, 1);
 
@@ -516,7 +495,6 @@ addressbook_component_init (AddressbookComponent *component)
 	}
 }
 
-
 /* Public API.  */
 
 AddressbookComponent *
@@ -538,7 +516,7 @@ addressbook_component_peek_gconf_client (AddressbookComponent *component)
 	return component->priv->gconf_client;
 }
 
-const char *
+const gchar *
 addressbook_component_peek_base_directory (AddressbookComponent *component)
 {
 	g_return_val_if_fail (ADDRESSBOOK_IS_COMPONENT (component), NULL);
