@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -29,7 +29,7 @@
 
 #include "eab-editor.h"
 #include "addressbook/gui/widgets/eab-gui-util.h"
-#include "e-contact-editor-marshal.h"
+#include "e-util/e-util.h"
 
 static void eab_editor_default_show  (EABEditor *editor);
 static void eab_editor_default_raise (EABEditor *editor);
@@ -142,7 +142,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_added),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
@@ -152,7 +152,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_modified),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
@@ -162,7 +162,7 @@ eab_editor_class_init (EABEditorClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EABEditorClass, contact_deleted),
 			      NULL, NULL,
-			      e_contact_editor_marshal_NONE__INT_OBJECT,
+			      e_marshal_NONE__INT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_INT, G_TYPE_OBJECT);
 
@@ -311,11 +311,11 @@ eab_editor_get_all_editors (void)
 }
 
 gboolean
-eab_editor_confirm_delete (GtkWindow *parent, gboolean plural, gboolean is_list, char *name)
+eab_editor_confirm_delete (GtkWindow *parent, gboolean plural, gboolean is_list, gchar *name)
 {
 	GtkWidget *dialog;
 	gint result;
-	char *msg;
+	gchar *msg;
 
 	if (is_list) {
 		/* contact list(s) */
@@ -354,7 +354,6 @@ eab_editor_confirm_delete (GtkWindow *parent, gboolean plural, gboolean is_list,
 	return (result == GTK_RESPONSE_ACCEPT);
 }
 
-
 void
 eab_editor_contact_added (EABEditor *editor, EBookStatus status, EContact *contact)
 {
