@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -52,7 +53,7 @@ eabp_target_free(EPopup *ep, EPopupTarget *t)
 	switch (t->type) {
 	case EAB_POPUP_TARGET_SELECT: {
 		EABPopupTargetSelect *s = (EABPopupTargetSelect *)t;
-		int i;
+		gint i;
 
 		for (i=0;i<s->cards->len;i++)
 			g_object_unref(s->cards->pdata[i]);
@@ -114,9 +115,9 @@ eab_popup_get_type(void)
 	return type;
 }
 
-EABPopup *eab_popup_new(const char *menuid)
+EABPopup *eab_popup_new(const gchar *menuid)
 {
-	EABPopup *eabp = g_object_new(eab_popup_get_type(), 0);
+	EABPopup *eabp = g_object_new(eab_popup_get_type(), NULL);
 
 	e_popup_construct(&eabp->popup, menuid);
 
@@ -131,13 +132,12 @@ EABPopup *eab_popup_new(const char *menuid)
  * @cards: Cards selected.  This will be freed on completion.
  *
  * Create a new selection popup target.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
 
-
 EABPopupTargetURI *
-eab_popup_target_new_uri(EABPopup *emp, const char *uri)
+eab_popup_target_new_uri(EABPopup *emp, const gchar *uri)
 {
 	EABPopupTargetURI *t = e_popup_target_new(&emp->popup, EAB_POPUP_TARGET_URI, sizeof(*t));
 	guint32 mask = ~0;
@@ -157,15 +157,12 @@ eab_popup_target_new_uri(EABPopup *emp, const char *uri)
 	return t;
 }
 
-
-
-
 EABPopupTargetSelect *
-eab_popup_target_new_select(EABPopup *eabp, struct _EBook *book, int readonly, GPtrArray *cards)
+eab_popup_target_new_select(EABPopup *eabp, struct _EBook *book, gint readonly, GPtrArray *cards)
 {
 	EABPopupTargetSelect *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SELECT, sizeof(*t));
 	guint32 mask = ~0;
-	int has_email = FALSE, i;
+	gint has_email = FALSE, i;
 
 	/* FIXME: duplicated in eab-menu.c */
 
@@ -180,7 +177,7 @@ eab_popup_target_new_select(EABPopup *eabp, struct _EBook *book, int readonly, G
 		email = e_contact_get(E_CONTACT(contact), E_CONTACT_EMAIL);
 		if (email) {
 			has_email = TRUE;
-			
+
 			g_list_foreach(email, (GFunc)g_free, NULL);
 			g_list_free(email);
 		}
@@ -218,7 +215,7 @@ eab_popup_target_new_source(EABPopup *eabp, ESourceSelector *selector)
 {
 	EABPopupTargetSource *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SOURCE, sizeof(*t));
 	guint32 mask = ~0;
-	const char *source_uri;
+	const gchar *source_uri;
 	ESource *source;
 
 	/* TODO: this is duplicated for calendar and tasks too */
@@ -246,7 +243,7 @@ eab_popup_target_new_source(EABPopup *eabp, ESourceSelector *selector)
 #ifdef ADAPTED_TO_E_NAME_SELECTOR
 
 EABPopupTargetSelectNames *
-eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *model, int row)
+eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *model, gint row)
 {
 	EABPopupTargetSelectNames *t = e_popup_target_new(&eabp->popup, EAB_POPUP_TARGET_SELECT_NAMES, sizeof(*t));
 
@@ -289,7 +286,7 @@ eab_popup_target_new_select_names(EABPopup *eabp, struct _ESelectNamesModel *mod
 
 */
 
-static void *eabph_parent_class;
+static gpointer eabph_parent_class;
 #define eabph ((EABPopupHook *)eph)
 
 static const EPopupHookTargetMask eabph_select_masks[] = {
@@ -298,24 +295,24 @@ static const EPopupHookTargetMask eabph_select_masks[] = {
 	{ "any", EAB_POPUP_SELECT_ANY },
 	{ "editable", EAB_POPUP_SELECT_EDITABLE },
 	{ "email", EAB_POPUP_SELECT_EMAIL },
-	{ 0 }
+	{ NULL }
 };
 
 static const EPopupHookTargetMask eabph_source_masks[] = {
 	{ "primary", EAB_POPUP_SOURCE_PRIMARY },
 	{ "system", EAB_POPUP_SOURCE_SYSTEM },
-	{ 0 }
+	{ NULL }
 };
 
 static const EPopupHookTargetMask eabph_uri_masks[] = {
 	{ "http", EAB_POPUP_URI_HTTP },
 	{ "internal-mailto", EAB_POPUP_URI_MAILTO },
 	{ "notmailto", EAB_POPUP_URI_NOT_MAILTO },
-	{ 0 }
+	{ NULL }
 };
 
 static const EPopupHookTargetMask eabph_select_names_masks[] = {
-	{ 0 }
+	{ NULL }
 };
 
 static const EPopupHookTargetMap eabph_targets[] = {
@@ -323,7 +320,7 @@ static const EPopupHookTargetMap eabph_targets[] = {
         { "uri", EAB_POPUP_TARGET_URI, eabph_uri_masks },
 	{ "source", EAB_POPUP_TARGET_SOURCE, eabph_source_masks },
 	{ "select-names", EAB_POPUP_TARGET_SELECT_NAMES, eabph_select_names_masks },
-	{ 0 }
+	{ NULL }
 };
 
 static void
@@ -337,7 +334,7 @@ eabph_finalise(GObject *o)
 static void
 eabph_class_init(EPluginHookClass *klass)
 {
-	int i;
+	gint i;
 
 	((GObjectClass *)klass)->finalize = eabph_finalise;
 	((EPluginHookClass *)klass)->id = "org.gnome.evolution.addressbook.popup:1.0";
@@ -352,7 +349,7 @@ GType
 eab_popup_hook_get_type(void)
 {
 	static GType type = 0;
-	
+
 	if (!type) {
 		static const GTypeInfo info = {
 			sizeof(EABPopupHookClass), NULL, NULL, (GClassInitFunc) eabph_class_init, NULL, NULL,
@@ -362,6 +359,6 @@ eab_popup_hook_get_type(void)
 		eabph_parent_class = g_type_class_ref(e_popup_hook_get_type());
 		type = g_type_register_static(e_popup_hook_get_type(), "EABPopupHook", &info, 0);
 	}
-	
+
 	return type;
 }
