@@ -76,7 +76,6 @@ file_open_event_cb (BonoboUIComponent *uic, gpointer data, const gchar *path)
 	e_calendar_view_open_event (E_CALENDAR_VIEW (gnome_calendar_get_current_view_widget (gcal)));
 }
 
-
 /* Prints the calendar at its current view and time range */
 void
 calendar_command_print (GnomeCalendar *gcal, GtkPrintOperationAction action)
@@ -92,6 +91,25 @@ calendar_command_print (GnomeCalendar *gcal, GtkPrintOperationAction action)
 		time_t start;
 
 		gnome_calendar_get_current_time_range (gcal, &start, NULL);
+
+		if (gnome_calendar_get_view (gcal) == GNOME_CAL_MONTH_VIEW) {
+			EWeekView *week_view = E_WEEK_VIEW (gnome_calendar_get_current_view_widget (gcal));
+
+			if (week_view && week_view->multi_week_view && week_view->weeks_shown >= 4 && g_date_valid (&week_view->first_day_shown)) {
+				GDate date = week_view->first_day_shown;
+				struct icaltimetype start_tt = icaltime_null_time ();
+
+				g_date_add_days (&date, 7);
+
+				start_tt.is_date = TRUE;
+				start_tt.year = g_date_get_year (&date);
+				start_tt.month = g_date_get_month (&date);
+				start_tt.day = g_date_get_day (&date);
+
+				start = icaltime_as_timet (start_tt);
+			}
+		}
+
 		print_calendar (gcal, action, start);
 	}
 }
@@ -225,7 +243,6 @@ show_month_view_clicked (BonoboUIComponent *uic, gpointer data, const gchar *pat
 	gnome_calendar_set_view (gcal, GNOME_CAL_MONTH_VIEW);
 }
 
-
 static void
 show_list_view_clicked (BonoboUIComponent *uic, gpointer data, const gchar *path)
 {
@@ -236,7 +253,6 @@ show_list_view_clicked (BonoboUIComponent *uic, gpointer data, const gchar *path
 	gnome_calendar_set_view (gcal, GNOME_CAL_LIST_VIEW);
 }
 
-
 static void
 cut_cmd (BonoboUIComponent *uic, gpointer data, const gchar *path)
 {
@@ -370,7 +386,7 @@ sensitize_items(BonoboUIComponent *uic, struct _sensitize_item *items, guint32 m
 
 static struct _sensitize_item calendar_sensitize_table[] = {
 	{ "EventOpen", E_CAL_MENU_SELECT_ONE },
-	{ "Cut", E_CAL_MENU_SELECT_EDITABLE },
+	{ "Cut", E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_ANY },
 	{ "Copy", E_CAL_MENU_SELECT_ANY },
 	{ "Paste", E_CAL_MENU_SELECT_EDITABLE },
 	{ "Delete", E_CAL_MENU_SELECT_EDITABLE|E_CAL_MENU_SELECT_NONRECURRING },
@@ -416,7 +432,7 @@ calendar_control_sensitize_calendar_commands (BonoboControl *control, GnomeCalen
 
 	t = e_cal_menu_target_new_select(menu, model, events);
 	if (!enable)
-		t->target.mask = ~0;
+		t->target.mask = ~((~t->target.mask) & E_CAL_MENU_SELECT_EDITABLE);
 
 	sensitize_items(uic, calendar_sensitize_table, t->target.mask);
 #if 0
@@ -432,7 +448,7 @@ calendar_control_sensitize_calendar_commands (BonoboControl *control, GnomeCalen
 }
 
 static struct _sensitize_item taskpad_sensitize_table[] = {
-	{ "Cut", E_CAL_MENU_SELECT_EDITABLE },
+	{ "Cut", E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_ANY },
 	{ "Copy", E_CAL_MENU_SELECT_ANY },
 	{ "Paste", E_CAL_MENU_SELECT_EDITABLE },
 	{ "Delete", E_CAL_MENU_SELECT_EDITABLE },
@@ -468,7 +484,7 @@ sensitize_taskpad_commands (GnomeCalendar *gcal, BonoboControl *control, gboolea
 
 	t = e_cal_menu_target_new_select(menu, model, events);
 	if (!enable)
-		t->target.mask = ~0;
+		t->target.mask = ~((~t->target.mask) & E_CAL_MENU_SELECT_EDITABLE);
 
 	sensitize_items(uic, taskpad_sensitize_table, t->target.mask);
 }
