@@ -60,6 +60,7 @@
 #include "cancel-comp.h"
 #include "recur-comp.h"
 #include "comp-editor.h"
+#include "comp-editor-util.h"
 #include "../e-cal-popup.h"
 #include "../calendar-config-keys.h"
 #include "cal-attachment-select-file.h"
@@ -74,6 +75,8 @@
 
 #define d(x)
 
+static gboolean comp_lite = FALSE;
+
 /* Private part of the CompEditor structure */
 struct _CompEditorPrivate {
 	/* Client to use */
@@ -391,6 +394,7 @@ save_comp (CompEditor *editor)
 	timezones = g_hash_table_new (g_str_hash, g_str_equal);
 
 	clone = e_cal_component_clone (priv->comp);
+	comp_editor_copy_new_attendees (clone, priv->comp);
 	for (l = priv->pages; l != NULL; l = l->next) {
 		if (!comp_editor_page_fill_component (l->data, clone)) {
 			g_object_unref (clone);
@@ -520,7 +524,7 @@ save_comp_with_send (CompEditor *editor)
 {
 	CompEditorPrivate *priv;
 	CompEditorFlags flags;
-	gboolean send;
+	gboolean send, delegated, only_new_attendees = FALSE;
 	gboolean delegate;
 	gboolean strip_alarms = TRUE;
 
@@ -542,7 +546,13 @@ save_comp_with_send (CompEditor *editor)
 	if (!save_comp (editor))
 		return FALSE;
 
-	if ((delegate && !e_cal_get_save_schedules (priv->client)) || (send && send_component_dialog ((GtkWindow *) editor, priv->client, priv->comp, !priv->existing_org, &strip_alarms))) {
+	delegated = delegate && !e_cal_get_save_schedules (priv->client);
+	if (delegated || (send && send_component_dialog ((GtkWindow *) editor, priv->client, priv->comp, !priv->existing_org, &strip_alarms, !priv->existing_org ? NULL : &only_new_attendees))) {
+		if (delegated)
+			only_new_attendees = FALSE;
+
+		comp_editor_set_flags (editor, (comp_editor_get_flags (editor) & (~COMP_EDITOR_SEND_TO_NEW_ATTENDEES_ONLY)) | (only_new_attendees ? COMP_EDITOR_SEND_TO_NEW_ATTENDEES_ONLY : 0));
+
 		if ((itip_organizer_is_user (priv->comp, priv->client) || itip_sentby_is_user (priv->comp, priv->client))) {
 			if (e_cal_component_get_vtype (priv->comp) == E_CAL_COMPONENT_JOURNAL)
 				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_PUBLISH, strip_alarms);
@@ -1536,6 +1546,7 @@ comp_editor_init (CompEditor *editor)
 	GtkAction *action;
 	GtkWidget *container;
 	GtkWidget *widget;
+	GtkWidget *scroll;
 	gint n_targets;
 	GError *error = NULL;
 
@@ -1552,6 +1563,8 @@ comp_editor_init (CompEditor *editor)
 
 	priv->ui_manager = gtk_ui_manager_new ();
 
+	if (comp_lite)
+		gtk_window_set_default_size ((GtkWindow *) editor, 800, 450);
 	gtk_window_add_accel_group (
 		GTK_WINDOW (editor),
 		gtk_ui_manager_get_accel_group (priv->ui_manager));
@@ -1625,9 +1638,11 @@ comp_editor_init (CompEditor *editor)
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
 	gtk_widget_show (widget);
 
-	widget = comp_editor_get_managed_widget (editor, "/main-toolbar");
-	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
-	gtk_widget_show (widget);
+	if (!comp_lite) {
+		widget = comp_editor_get_managed_widget (editor, "/main-toolbar");
+		gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+		gtk_widget_show (widget);
+	}
 
 	widget = e_attachment_paned_new ();
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
@@ -1635,15 +1650,60 @@ comp_editor_init (CompEditor *editor)
 	priv->attachment_view = g_object_ref (widget);
 	gtk_widget_show (widget);
 
+	if (comp_lite) {
+		GtkWidget *tmp, *tmp1, *tmp_box, *cont;
+		GtkWidget *combo;
+
+		e_attachment_paned_set_expanded (E_ATTACHMENT_PANED (widget), TRUE);
+		e_attachment_paned_set_expanded (E_ATTACHMENT_PANED (widget), FALSE);
+
+		combo = e_attachment_paned_get_view_combo (
+			E_ATTACHMENT_PANED (widget));
+		gtk_widget_hide (combo);
+		cont = e_attachment_paned_get_controls_container (
+			E_ATTACHMENT_PANED (widget));
+
+		tmp_box = gtk_hbox_new (FALSE, 0);
+		tmp = gtk_hbox_new (FALSE, 0);
+		tmp1 = gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_BUTTON);
+		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 0);
+		tmp1 = gtk_label_new_with_mnemonic (_("Save"));
+		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 3);
+		gtk_widget_show_all(tmp);
+
+		combo = gtk_ui_manager_get_widget (priv->ui_manager, "/main-toolbar/save");
+		gtk_widget_reparent (combo, tmp_box);
+		gtk_box_set_child_packing ((GtkBox *)tmp_box, combo, FALSE, FALSE, 6, GTK_PACK_END);
+		gtk_tool_item_set_is_important (GTK_TOOL_ITEM (combo), TRUE);
+		combo = gtk_bin_get_child ((GtkBin *)combo);
+		gtk_container_remove((GtkContainer *)combo, gtk_bin_get_child ((GtkBin *)combo));
+		gtk_container_add((GtkContainer *)combo, tmp);
+		gtk_button_set_relief ((GtkButton *)combo, GTK_RELIEF_NORMAL);
+
+		gtk_widget_show(tmp_box);
+		gtk_box_pack_end (GTK_BOX (cont), tmp_box, FALSE, FALSE, 4);
+
+	}
 	container = e_attachment_paned_get_content_area (
 		E_ATTACHMENT_PANED (priv->attachment_view));
 
+	if (comp_lite) {
+		scroll = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy ((GtkScrolledWindow *)scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		gtk_widget_show(scroll);
+		gtk_box_pack_start (GTK_BOX (container), scroll, TRUE, TRUE, 0);
+	}
+
 	widget = gtk_notebook_new ();
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (widget), FALSE);
-	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
+	if (!comp_lite)
+		gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
+	else
+		gtk_scrolled_window_add_with_viewport ((GtkScrolledWindow *) scroll, widget);
 	priv->notebook = GTK_NOTEBOOK (widget);
 	gtk_widget_show (widget);
-
+	if (comp_lite)
+		gtk_widget_set_size_request (scroll, 300, -1);
 	comp_editor_setup_recent_menu (editor);
 
 	/* Drag-and-Drop Support */
@@ -2377,8 +2437,10 @@ real_edit_comp (CompEditor *editor, ECalComponent *comp)
 		priv->comp = NULL;
 	}
 
-	if (comp)
+	if (comp) {
 		priv->comp = e_cal_component_clone (comp);
+		comp_editor_copy_new_attendees (priv->comp, comp);
+	}
 
 	priv->existing_org = e_cal_component_has_organizer (comp);
 	priv->warned = FALSE;
@@ -2484,6 +2546,8 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 	if (!send_comp)
 		send_comp = e_cal_component_clone (priv->comp);
 
+	comp_editor_copy_new_attendees (send_comp, priv->comp);
+
 	if (e_cal_component_get_vtype (send_comp) == E_CAL_COMPONENT_JOURNAL)
 		get_users_from_memo_comp (send_comp, &users);
 
@@ -2498,27 +2562,32 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 	if (!e_cal_component_has_attachments (priv->comp)
 	  || e_cal_get_static_capability (priv->client, CAL_STATIC_CAPABILITY_CREATE_MESSAGES)) {
 		if (itip_send_comp (method, send_comp, priv->client,
-					NULL, NULL, users, strip_alarms)) {
+					NULL, NULL, users, strip_alarms, priv->flags & COMP_EDITOR_SEND_TO_NEW_ATTENDEES_ONLY)) {
 			g_object_unref (send_comp);
 			return TRUE;
 		}
 	} else {
 		/* Clone the component with attachments set to CID:...  */
-		gint num_attachments, i;
 		GSList *attach_list = NULL;
-		GSList *mime_attach_list;
-
-		num_attachments = e_cal_component_get_num_attachments (send_comp);
-
-		for (i = 0; i < num_attachments; i++) {
-			attach_list = g_slist_append (attach_list, g_strdup ("CID:..."));
-		}
-		e_cal_component_set_attachment_list (send_comp, attach_list);
+		GSList *mime_attach_list, *attach;
 
 		/* mime_attach_list is freed by itip_send_comp */
 		mime_attach_list = comp_editor_get_mime_attach_list (editor);
+
+		for (attach = mime_attach_list; attach; attach = attach->next) {
+			struct CalMimeAttach *cma = (struct CalMimeAttach *) attach->data;
+
+			attach_list = g_slist_append (attach_list, cma->content_id);
+		}
+
+		if (attach_list) {
+			e_cal_component_set_attachment_list (send_comp, attach_list);
+
+			g_slist_free (attach_list);
+		}
+
 		if (itip_send_comp (method, send_comp, priv->client,
-					NULL, mime_attach_list, users, strip_alarms)) {
+					NULL, mime_attach_list, users, strip_alarms, priv->flags & COMP_EDITOR_SEND_TO_NEW_ATTENDEES_ONLY)) {
 			gboolean saved = save_comp (editor);
 
 			g_object_unref (send_comp);
@@ -2588,6 +2657,7 @@ comp_editor_get_current_comp (CompEditor *editor, gboolean *correct)
 	priv = editor->priv;
 
 	comp = e_cal_component_clone (priv->comp);
+	comp_editor_copy_new_attendees (comp, priv->comp);
 	if (priv->changed) {
 		for (l = priv->pages; l != NULL; l = l->next)
 			all_ok = comp_editor_page_fill_component (l->data, comp) && all_ok;
@@ -2721,6 +2791,8 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		camel_data_wrapper_decode_to_stream (wrapper, (CamelStream *) mstream);
 		buffer = g_memdup (mstream->buffer->data, mstream->buffer->len);
 
+		camel_mime_part_set_content_id (mime_part, NULL);
+
 		cal_mime_attach->encoded_data = (gchar *)buffer;
 		cal_mime_attach->length = mstream->buffer->len;
 		cal_mime_attach->filename = g_strdup (camel_mime_part_get_filename (mime_part));
@@ -2729,6 +2801,7 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 			desc = _("attachment");
 		cal_mime_attach->description = g_strdup (desc);
 		cal_mime_attach->content_type = g_strdup (camel_data_wrapper_get_mime_type (wrapper));
+		cal_mime_attach->content_id = g_strdup (camel_mime_part_get_content_id (mime_part));
 
 		disp = camel_mime_part_get_disposition (mime_part);
 		if (disp && !g_ascii_strcasecmp(disp, "inline"))
@@ -2809,3 +2882,14 @@ obj_removed_cb (ECal *client, GList *uids, gpointer data)
 		close_dialog (editor);
 }
 
+gboolean
+comp_editor_get_lite ()
+{
+	return comp_lite;
+}
+
+void
+comp_editor_set_lite (gboolean status)
+{
+	comp_lite = status;
+}
