@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,15 +35,15 @@
 #include <mail/em-config.h>
 #include <mail/em-event.h>
 #include <camel/camel-mime-message.h>
+#include <composer/e-msg-composer.h>
 
 #include "bbdb.h"
 
 #define d(x)
 
 /* Plugin hooks */
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
-void bbdb_handle_reply (EPlugin *ep, EMEventTargetMessage *target);
-GtkWidget *bbdb_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
+void bbdb_handle_send (EPlugin *ep, EMEventTargetComposer *target);
 GtkWidget *bbdb_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data);
 
 /* For internal use */
@@ -59,11 +59,11 @@ struct bbdb_stuff {
 
 /* Static forward declarations */
 static gboolean bbdb_timeout (gpointer data);
-static void bbdb_do_it (EBook *book, const char *name, const char *email);
-static void add_email_to_contact (EContact *contact, const char *email);
+static void bbdb_do_it (EBook *book, const gchar *name, const gchar *email);
+static void add_email_to_contact (EContact *contact, const gchar *email);
 static void enable_toggled_cb (GtkWidget *widget, gpointer data);
 static void source_changed_cb (ESourceComboBox *source_combo_box, struct bbdb_stuff *stuff);
-static GtkWidget *create_addressbook_option_menu (struct bbdb_stuff *stuff, int type);
+static GtkWidget *create_addressbook_option_menu (struct bbdb_stuff *stuff, gint type);
 static void cleanup_cb (GObject *o, gpointer data);
 
 static ESource *
@@ -105,10 +105,10 @@ find_esource_by_uri (ESourceList *source_list, const gchar *target_uri)
 	return NULL;
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
- 	/* Start up the plugin. */
+	/* Start up the plugin. */
 	if (enable) {
 		d(fprintf (stderr, "BBDB spinning up...\n"));
 
@@ -134,8 +134,8 @@ bbdb_timeout (gpointer data)
 
 typedef struct
 {
-	char *name;
-	char *email;
+	gchar *name;
+	gchar *email;
 } todo_struct;
 
 static void
@@ -192,7 +192,7 @@ bbdb_do_in_thread (gpointer data)
 }
 
 static void
-bbdb_do_thread (const char *name, const char *email)
+bbdb_do_thread (const gchar *name, const gchar *email)
 {
 	todo_struct *td;
 
@@ -227,53 +227,53 @@ bbdb_do_thread (const char *name, const char *email)
 	G_UNLOCK (todo);
 }
 
-/* Code to populate addressbook when you reply to a mail follows */
-void
-bbdb_handle_reply (EPlugin *ep, EMEventTargetMessage *target)
+static void
+walk_destinations_and_free (EDestination **dests)
 {
-	const CamelInternetAddress *cia;
-	int         i;
+	gint i;
 
-	cia = camel_mime_message_get_from (target->message);
-	if (cia) {
-		for (i = 0; i < camel_address_length (CAMEL_ADDRESS (cia)); i ++) {
-			const char *name=NULL, *email=NULL;
-			if (!(camel_internet_address_get (cia, i, &name, &email)))
-				continue;
-			bbdb_do_thread (name, email);
-		}
-	}
-
-	/* If this is a reply-all event, process To: and Cc: also. */
-	if (((EEventTarget *) target)->mask & EM_EVENT_MESSAGE_REPLY_ALL) {
+	if (!dests)
 		return;
+
+	for (i = 0; dests[i] != NULL; i++) {
+		const gchar *name, *addr;
+
+		name = e_destination_get_name (dests[i]);
+		addr = e_destination_get_email (dests[i]);
+
+		if (name || addr)
+			bbdb_do_thread (name, addr);
 	}
 
-	cia = camel_mime_message_get_recipients (target->message, CAMEL_RECIPIENT_TYPE_TO);
-	if (cia) {
-		for (i = 0; i < camel_address_length (CAMEL_ADDRESS (cia)); i ++) {
-			const char *name=NULL, *email=NULL;
-			if (!(camel_internet_address_get (cia, i, &name, &email)))
-				continue;
-			bbdb_do_thread (name, email);
-		}
-	}
+	e_destination_freev (dests);
+}
 
-	cia = camel_mime_message_get_recipients (target->message, CAMEL_RECIPIENT_TYPE_CC);
-	if (cia) {
-		for (i = 0; i < camel_address_length (CAMEL_ADDRESS (cia)); i ++) {
-			const char *name=NULL, *email=NULL;
-			if (!(camel_internet_address_get (cia, i, &name, &email)))
-				continue;
-			bbdb_do_thread (name, email);
-		}
-	}
+void
+bbdb_handle_send (EPlugin *ep, EMEventTargetComposer *target)
+{
+	EComposerHeaderTable *table;
+	GConfClient *gconf;
+	gboolean enable;
+
+	gconf = gconf_client_get_default ();
+	enable = gconf_client_get_bool (gconf, GCONF_KEY_ENABLE, NULL);
+	g_object_unref (gconf);
+
+	if (!enable)
+		return;
+
+	table = e_msg_composer_get_header_table (target->composer);
+	g_return_if_fail (table);
+
+	/* read information from the composer, not from a generated message */
+	walk_destinations_and_free (e_composer_header_table_get_destinations_to (table));
+	walk_destinations_and_free (e_composer_header_table_get_destinations_cc (table));
 }
 
 static void
-bbdb_do_it (EBook *book, const char *name, const char *email)
+bbdb_do_it (EBook *book, const gchar *name, const gchar *email)
 {
-	char *query_string, *delim, *temp_name = NULL;
+	gchar *query_string, *delim, *temp_name = NULL;
 	EBookQuery *query;
 	GList *contacts, *l;
 	EContact *contact;
@@ -375,10 +375,10 @@ bbdb_do_it (EBook *book, const char *name, const char *email)
 }
 
 EBook *
-bbdb_open_addressbook (int type)
+bbdb_open_addressbook (gint type)
 {
 	GConfClient *gconf;
-	char        *uri;
+	gchar        *uri;
 	EBook       *book = NULL;
 
 	gboolean     status;
@@ -439,7 +439,7 @@ bbdb_check_gaim_enabled (void)
 }
 
 static void
-add_email_to_contact (EContact *contact, const char *email)
+add_email_to_contact (EContact *contact, const gchar *email)
 {
 	GList *emails;
 
@@ -448,8 +448,6 @@ add_email_to_contact (EContact *contact, const char *email)
 	e_contact_set (contact, E_CONTACT_EMAIL, (gpointer) emails);
 }
 
-
-
 /* Code to implement the configuration user interface follows */
 
 static void
@@ -458,6 +456,7 @@ enable_toggled_cb (GtkWidget *widget, gpointer data)
 	struct bbdb_stuff *stuff = (struct bbdb_stuff *) data;
 	gboolean active;
 	ESource *selected_source;
+	gchar *addressbook;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
@@ -465,7 +464,10 @@ enable_toggled_cb (GtkWidget *widget, gpointer data)
 	gconf_client_set_bool (stuff->target->gconf, GCONF_KEY_ENABLE, active, NULL);
 
 	gtk_widget_set_sensitive (stuff->option_menu, active);
-	if (active && !gconf_client_get_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK, NULL)) {
+
+	addressbook = gconf_client_get_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK, NULL);
+
+	if (active && !addressbook) {
 		const gchar *uri = NULL;
 		GError *error = NULL;
 
@@ -484,6 +486,7 @@ enable_toggled_cb (GtkWidget *widget, gpointer data)
 			g_error_free (error);
 		}
 	}
+	g_free (addressbook);
 }
 
 static void
@@ -492,18 +495,22 @@ enable_gaim_toggled_cb (GtkWidget *widget, gpointer data)
 	struct bbdb_stuff *stuff = (struct bbdb_stuff *) data;
 	gboolean active;
 	ESource *selected_source;
+	gchar *addressbook_gaim;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
 	/* Save the new setting to gconf */
 	gconf_client_set_bool (stuff->target->gconf, GCONF_KEY_ENABLE_GAIM, active, NULL);
 
+	addressbook_gaim = gconf_client_get_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK_GAIM, NULL);
 	gtk_widget_set_sensitive (stuff->gaim_option_menu, active);
-	if (active && !gconf_client_get_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK_GAIM, NULL)) {
+	if (active && !addressbook_gaim) {
 		selected_source = e_source_combo_box_get_active (
 			E_SOURCE_COMBO_BOX (stuff->gaim_option_menu));
 		gconf_client_set_string (stuff->target->gconf, GCONF_KEY_WHICH_ADDRESSBOOK_GAIM, e_source_get_uri (selected_source), NULL);
 	}
+
+	g_free (addressbook_gaim);
 }
 
 static void
@@ -553,12 +560,12 @@ gaim_source_changed_cb (ESourceComboBox *source_combo_box,
 }
 
 static GtkWidget *
-create_addressbook_option_menu (struct bbdb_stuff *stuff, int type)
+create_addressbook_option_menu (struct bbdb_stuff *stuff, gint type)
 {
 	GtkWidget   *combo_box;
 	ESourceList *source_list;
 	ESource     *selected_source;
-	char        *selected_source_uri;
+	gchar        *selected_source_uri;
 
 	GConfClient *gconf = stuff->target->gconf;
 
@@ -636,7 +643,7 @@ bbdb_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	gtk_box_pack_start (GTK_BOX (hbox), inner_vbox, FALSE, FALSE, 0);
 
 	/* Enable BBDB checkbox */
-	check = gtk_check_button_new_with_mnemonic (_("_Auto-create address book entries when replying to messages"));
+	check = gtk_check_button_new_with_mnemonic (_("Create _address book entries when sending mails"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), gconf_client_get_bool (target->gconf, GCONF_KEY_ENABLE, NULL));
 	g_signal_connect (GTK_TOGGLE_BUTTON (check), "toggled", G_CALLBACK (enable_toggled_cb), stuff);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), check, FALSE, FALSE, 0);
