@@ -36,6 +36,8 @@
 #include <e-util/e-plugin.h>
 
 #include <calendar/gui/e-cal-config.h>
+#include <calendar/gui/e-cal-event.h>
+#include <calendar/gui/calendar-component.h>
 
 #include <libedataserver/e-url.h>
 #include <libedataserver/e-account-list.h>
@@ -49,25 +51,23 @@
 
 #include "google-contacts-source.h"
 
-#define CALENDAR_LOCATION "http://www.google.com/calendar/feeds/"
+#define GOOGLE_BASE_URI "google://"
+#define CALENDAR_LOCATION "://www.google.com/calendar/feeds/"
 #define CALENDAR_DEFAULT_PATH "/private/full"
-#define URL_GET_SUBSCRIBED_CALENDARS "http://www.google.com/calendar/feeds/default/allcalendars/full"
+#define URL_GET_SUBSCRIBED_CALENDARS "://www.google.com/calendar/feeds/default/allcalendars/full"
+#define CALENDAR_CALDAV_URI "caldav://%s@www.google.com/calendar/dav/%s/events"
 
 #define d(x)
 
 /*****************************************************************************/
 /* prototypes */
-gint              e_plugin_lib_enable      (EPluginLib                 *ep,
-					   gint                         enable);
-
-GtkWidget *      plugin_google               (EPlugin                    *epl,
-					   EConfigHookItemFactoryData *data);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
+GtkWidget *plugin_google (EPlugin *epl, EConfigHookItemFactoryData *data);
+void e_calendar_google_migrate (EPlugin *epl, ECalEventTargetComponent *data);
 
 /*****************************************************************************/
 /* plugin intialization */
 
-
-
 static void
 ensure_google_source_group (void)
 {
@@ -78,7 +78,7 @@ ensure_google_source_group (void)
 		return;
 	}
 
-	e_source_list_ensure_group (slist, _("Google"), "google://", FALSE);
+	e_source_list_ensure_group (slist, _("Google"), GOOGLE_BASE_URI, FALSE);
 	g_object_unref (slist);
 }
 
@@ -97,22 +97,24 @@ e_plugin_lib_enable (EPluginLib *ep, gint enable)
 	return 0;
 }
 
-
 /********************************************************************************************************************/
-#if 0
 
-FIXME: Not sure why this function is declared but called no where. This needs fixing.
-
-static void
-ssl_changed (GtkToggleButton *button, ESource *source)
+static gchar *
+decode_at_back (const gchar *user)
 {
-	e_source_set_property(source, "ssl",
-			      gtk_toggle_button_get_active(button) ? "1" : "0");
+	gchar *res, *at;
+
+	g_return_val_if_fail (user != NULL, NULL);
+
+	res = g_strdup (user);
+	while (at = strstr (res, "%40"), at != NULL) {
+		*at = '@';
+		memmove (at + 1, at + 3, strlen (at + 3) + 1);
+	}
+
+	return res;
 }
 
-#endif
-
-
 static gboolean
 is_email (const gchar *address)
 {
@@ -134,7 +136,9 @@ sanitize_user_mail (const gchar *user)
 	if (!user)
 		return NULL;
 
-	if (!is_email (user)) {
+	if (strstr (user, "%40") != NULL) {
+		return g_strdup (user);
+	} else if (!is_email (user)) {
 		return g_strconcat (user, "%40gmail.com", NULL);
 	} else {
 		gchar *tmp = g_malloc0 (sizeof (gchar) * (1 + strlen (user) + 2));
@@ -149,12 +153,12 @@ sanitize_user_mail (const gchar *user)
 }
 
 static gchar *
-construct_default_uri (const gchar *username)
+construct_default_uri (const gchar *username, gboolean is_ssl)
 {
 	gchar *user, *uri;
 
 	user = sanitize_user_mail (username);
-	uri = g_strconcat (CALENDAR_LOCATION, user, CALENDAR_DEFAULT_PATH, NULL);
+	uri = g_strconcat (is_ssl ? "https" : "http", CALENDAR_LOCATION, user, CALENDAR_DEFAULT_PATH, NULL);
 	g_free (user);
 
 	return uri;
@@ -165,68 +169,135 @@ static gboolean
 is_default_uri (const gchar *given_uri, const gchar *username)
 {
 	gchar *uri, *at;
-	gint ats;
-	gboolean res;
+	gint ats, i;
+	gboolean res = FALSE;
 
 	if (!given_uri)
 		return TRUE;
 
-	uri = construct_default_uri (username);
+	for (i = 0; !res && i < 2; i++) {
+		/* try both versions here, with and without ssl */
+		uri = construct_default_uri (username, i == 0);
 
-	/* count number of '@' in given_uri to know how much memory will be required */
-	ats = 0;
-	for (at = strchr (given_uri, '@'); at; at = strchr (at + 1, '@')) {
-		ats++;
-	}
-
-	if (!ats)
-		res = g_ascii_strcasecmp (given_uri, uri) == 0;
-	else {
-		const gchar *last;
-		gchar *tmp = g_malloc0 (sizeof (gchar) * (1 + strlen (given_uri) + (2 * ats)));
-
-		last = given_uri;
-		for (at = strchr (last, '@'); at; at = strchr (at + 1, '@')) {
-			strncat (tmp, last, at - last);
-			strcat (tmp, "%40");
-			last = at + 1;
+		/* count number of '@' in given_uri to know how much memory will be required */
+		ats = 0;
+		for (at = strchr (given_uri, '@'); at; at = strchr (at + 1, '@')) {
+			ats++;
 		}
-		strcat (tmp, last);
 
-		res = g_ascii_strcasecmp (tmp, uri) == 0;
+		if (!ats)
+			res = g_ascii_strcasecmp (given_uri, uri) == 0;
+		else {
+			const gchar *last;
+			gchar *tmp = g_malloc0 (sizeof (gchar) * (1 + strlen (given_uri) + (2 * ats)));
 
-		g_free (tmp);
+			last = given_uri;
+			for (at = strchr (last, '@'); at; at = strchr (at + 1, '@')) {
+				strncat (tmp, last, at - last);
+				strcat (tmp, "%40");
+				last = at + 1;
+			}
+			strcat (tmp, last);
+
+			res = g_ascii_strcasecmp (tmp, uri) == 0;
+
+			g_free (tmp);
+		}
+
+		g_free (uri);
 	}
 
-	g_free (uri);
-
 	return res;
 }
 
+static void
+update_source_uris (ESource *source, const gchar *uri)
+{
+	gchar *abs_uri, *tmp, *user_sanitized, *slash;
+	const gchar *user, *feeds;
+
+	g_return_if_fail (source != NULL);
+	g_return_if_fail (uri != NULL);
+
+	/* this also changes an absolute uri */
+	e_source_set_relative_uri (source, uri);
+
+	user = e_source_get_property (source, "username");
+	g_return_if_fail (user != NULL);
+
+	feeds = strstr (uri, "/feeds/");
+	g_return_if_fail (feeds != NULL);
+	feeds += 7;
+
+	user_sanitized = sanitize_user_mail (user);
+	/* no "%40" in the URL path for caldav, really */
+	tmp = decode_at_back (feeds);
+
+	slash = strchr (tmp, '/');
+	if (slash)
+		*slash = '\0';
+
+	abs_uri = g_strdup_printf (CALENDAR_CALDAV_URI, user_sanitized, tmp);
+	e_source_set_absolute_uri (source, abs_uri);
+
+	g_free (abs_uri);
+	g_free (tmp);
+	g_free (user_sanitized);
+}
+
 static void init_combo_values (GtkComboBox *combo, const gchar *deftitle, const gchar *defuri);
 
 static void
-user_changed (GtkEntry *editable, ESource *source)
+update_user_in_source (ESource *source, const gchar *new_user)
 {
-	gchar       *uri;
-	const gchar *user;
+	gchar       *uri, *eml, *user;
+	const gchar *ssl;
+
+	/* to ensure it will not be freed before the work with it is done */
+	user = g_strdup (new_user);
 
 	/* two reasons why set readonly to FALSE:
 	   a) the e_source_set_relative_uri does nothing for readonly sources
 	   b) we are going to set default uri, which should be always writeable */
 	e_source_set_readonly (source, FALSE);
 
-	user = gtk_entry_get_text (GTK_ENTRY (editable));
-	uri = construct_default_uri (user);
-	e_source_set_relative_uri (source, uri);
+	if (user && *user) {
+		/* store the non-encoded email in the "username" property */
+		if (strstr (user, "@") == NULL && strstr (user, "%40") == NULL)
+			eml = g_strconcat (user, "@gmail.com", NULL);
+		else
+			eml = decode_at_back (user);
+	} else {
+		eml = NULL;
+	}
+
+	/* set username first, as it's used in update_source_uris */
+	e_source_set_property (source, "username", eml);
+
+	ssl = e_source_get_property (source, "ssl");
+	uri = construct_default_uri (user, !ssl || g_str_equal (ssl, "1"));
+	update_source_uris (source, uri);
 	g_free (uri);
 
-	e_source_set_property (source, "username", user);
-	e_source_set_property (source, "protocol", "google");
-	e_source_set_property (source, "auth-domain", "google");
+	/* "setup-username" is used to this plugin only, to keep what user wrote,
+	   not what uses the backend */
+	e_source_set_property (source, "setup-username", user);
 	e_source_set_property (source, "auth", (user && *user) ? "1" : NULL);
 	e_source_set_property (source, "googlename", NULL);
 
+	/* delete obsolete properties */
+	e_source_set_property (source, "protocol", NULL);
+	e_source_set_property (source, "auth-domain", NULL);
+
+	g_free (eml);
+	g_free (user);
+}
+
+static void
+user_changed (GtkEntry *editable, ESource *source)
+{
+	update_user_in_source (source, gtk_entry_get_text (GTK_ENTRY (editable)));
+
 	/* we changed user, thus reset the chosen calendar combo too, because
 	   other user means other calendars subscribed */
 	init_combo_values (GTK_COMBO_BOX (g_object_get_data (G_OBJECT (editable), "CalendarCombo")), _("Default"), NULL);
@@ -360,8 +431,10 @@ cal_combo_changed (GtkComboBox *combo, ESource *source)
 
 		gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, COL_TITLE, &title, COL_URL_PATH, &uri, COL_READ_ONLY, &readonly, -1);
 
-		if (!uri)
-			uri = construct_default_uri (e_source_get_property (source, "username"));
+		if (!uri) {
+			const gchar *ssl = e_source_get_property (source, "ssl");
+			uri = construct_default_uri (e_source_get_property (source, "username"), !ssl || g_str_equal (ssl, "1"));
+		}
 
 		if (is_default_uri (uri, e_source_get_property (source, "username"))) {
 			/* do not store title when we use default uri */
@@ -371,11 +444,13 @@ cal_combo_changed (GtkComboBox *combo, ESource *source)
 
 		/* first set readonly to FALSE, otherwise if TRUE, then e_source_set_readonly does nothing */
 		e_source_set_readonly (source, FALSE);
-		e_source_set_relative_uri (source, uri);
+		update_source_uris (source, uri);
 		e_source_set_readonly (source, readonly);
 		e_source_set_property (source, "googlename", title);
-		e_source_set_property (source, "protocol", "google");
-		e_source_set_property (source, "auth-domain", "google");
+
+		/* delete obsolete properties */
+		e_source_set_property (source, "protocol", NULL);
+		e_source_set_property (source, "auth-domain", NULL);
 
 		g_free (title);
 		g_free (uri);
@@ -403,8 +478,9 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	ESource *source;
 	GDataGoogleService *service;
 	GDataFeed *feed;
-	gchar *password, *tmp;
-	const gchar *username;
+	gchar *user, *password, *tmp;
+	const gchar *username, *ssl;
+	gchar *get_subscribed_url;
 	GError *error = NULL;
 	GtkWindow *parent;
 
@@ -419,22 +495,28 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	username = e_source_get_property (source, "username");
 	g_return_if_fail (username != NULL && *username != '\0');
 
-	tmp = g_strdup_printf (_("Enter password for user %s to access list of subscribed calendars."), username);
+	user = decode_at_back (username);
+	tmp = g_strdup_printf (_("Enter password for user %s to access list of subscribed calendars."), user);
 	password = e_passwords_ask_password (_("Enter password"), "Calendar", "", tmp,
 			E_PASSWORDS_REMEMBER_NEVER | E_PASSWORDS_REPROMPT | E_PASSWORDS_SECRET | E_PASSWORDS_DISABLE_REMEMBER,
 			NULL, parent);
 	g_free (tmp);
 
-	if (!password)
+	if (!password) {
+		g_free (user);
 		return;
+	}
 
 	service = gdata_google_service_new ("cl", "evolution-client-0.0.1");
-	gdata_service_set_credentials (GDATA_SERVICE (service), username, password);
+	gdata_service_set_credentials (GDATA_SERVICE (service), user, password);
 	/* privacy... maybe... */
 	memset (password, 0, strlen (password));
 	g_free (password);
 
-	feed = gdata_service_get_feed (GDATA_SERVICE (service), URL_GET_SUBSCRIBED_CALENDARS, &error);
+	ssl = e_source_get_property (source, "ssl");
+	get_subscribed_url = g_strconcat ((!ssl || g_str_equal (ssl, "1")) ? "https" : "http", URL_GET_SUBSCRIBED_CALENDARS, NULL);
+	feed = gdata_service_get_feed (GDATA_SERVICE (service), get_subscribed_url, &error);
+	g_free (get_subscribed_url);
 
 	if (feed) {
 		GSList *l;
@@ -484,7 +566,7 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 				if (color)
 					gdk_color_parse (color, &gdkcolor);
 
-				if (default_idx == -1 && is_default_uri (uri, username)) {
+				if (default_idx == -1 && is_default_uri (uri, user)) {
 					/* have the default uri always NULL and first in the combo */
 					uri = NULL;
 					gtk_list_store_insert (store, &iter, 0);
@@ -530,6 +612,7 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	}
 
 	g_object_unref (service);
+	g_free (user);
 }
 
 static void
@@ -553,7 +636,6 @@ plugin_google  (EPlugin                    *epl,
 	ESourceGroup *group;
 	EUri         *euri;
 	GtkWidget    *parent;
-	GtkWidget    *cssl;
 	GtkWidget    *widget;
 	GtkWidget    *luser;
 	GtkWidget    *user;
@@ -561,8 +643,6 @@ plugin_google  (EPlugin                    *epl,
 	GtkWidget    *combo;
 	gchar         *uri;
 	const gchar   *username;
-	const gchar   *ssl_prop;
-	gboolean      ssl_enabled;
 	gint           row;
 	GtkCellRenderer *renderer;
 	GtkListStore *store;
@@ -573,7 +653,7 @@ plugin_google  (EPlugin                    *epl,
 	group = e_source_peek_group (source);
 
 	widget = NULL;
-	if (g_ascii_strncasecmp ("google://", e_source_group_peek_base_uri (group), 9) != 0) {
+	if (g_ascii_strncasecmp (GOOGLE_BASE_URI, e_source_group_peek_base_uri (group), strlen (GOOGLE_BASE_URI)) != 0) {
 		return NULL;
 	}
 
@@ -585,31 +665,19 @@ plugin_google  (EPlugin                    *epl,
 		return NULL;
 	}
 
-	username = e_source_get_property (source, "username");
-	g_free (euri->user);
-	euri->user = NULL;
-	uri = e_uri_to_string (euri, FALSE);
+	e_uri_free (euri);
 
-	ssl_prop = e_source_get_property (source, "ssl");
-	if (ssl_prop && ssl_prop[0] == '1') {
-		ssl_enabled = TRUE;
-	} else {
-		ssl_enabled = FALSE;
-	}
+	username = e_source_get_property (source, "setup-username");
+	if (!username)
+		username = e_source_get_property (source, "username");
 
+	/* google's CalDAV requires SSL, thus forcing it here, and no setup for it */
 	e_source_set_property (source, "ssl", "1");
 
 	/* Build up the UI */
 	parent = data->parent;
 	row = GTK_TABLE (parent)->nrows;
 
-	cssl = gtk_check_button_new_with_mnemonic (_("Use _SSL"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cssl), ssl_enabled);
-	gtk_widget_show (cssl);
-	gtk_table_attach (GTK_TABLE (parent),
-			  cssl, 1, 2,
-			  row + 3, row + 4,
-			  GTK_FILL, 0, 0, 0);
 	luser = gtk_label_new_with_mnemonic (_("User_name:"));
 	gtk_widget_show (luser);
 	gtk_misc_set_alignment (GTK_MISC (luser), 0.0, 0.5);
@@ -636,7 +704,6 @@ plugin_google  (EPlugin                    *epl,
 			  row + 2, row + 3,
 			 GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_widget_show (hbox);
 
@@ -669,12 +736,10 @@ plugin_google  (EPlugin                    *epl,
 			  G_CALLBACK (user_changed),
 			  source);
 
-        g_free (uri);
-
 	label = gtk_label_new_with_mnemonic (_("Cal_endar:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (parent), label, 0, 1, row + 4, row + 5, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE (parent), label, 0, 1, row + 3, row + 4, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 
 	store = gtk_list_store_new (
 		NUM_COLUMNS,
@@ -711,10 +776,43 @@ plugin_google  (EPlugin                    *epl,
 	g_signal_connect (user, "changed", G_CALLBACK (retrieve_list_sensitize), label);
 	g_object_set_data (G_OBJECT (label), "ESource", source);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	gtk_widget_set_sensitive (label, FALSE);
+	gtk_widget_set_sensitive (label, username && *username);
 
 	gtk_widget_show_all (hbox);
-	gtk_table_attach (GTK_TABLE (parent), hbox, 1, 2, row + 4, row + 5, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE (parent), hbox, 1, 2, row + 3, row + 4, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 
 	return widget;
 }
+
+void
+e_calendar_google_migrate (EPlugin *epl, ECalEventTargetComponent *data)
+{
+	CalendarComponent *component;
+	ESourceList *source_list;
+	ESourceGroup *google = NULL;
+	gboolean changed = FALSE;
+
+	component = data->component;
+	source_list = calendar_component_peek_source_list (component);
+
+	google = e_source_list_peek_group_by_base_uri (source_list, GOOGLE_BASE_URI);
+	if (google) {
+		GSList *s;
+
+		for (s = e_source_group_peek_sources (google); s; s = s->next) {
+			ESource *source = E_SOURCE (s->data);
+
+			if (!source)
+				continue;
+
+			/* new source through CalDAV uses absolute uri, thus it should be migrated if not set */
+			if (!e_source_peek_absolute_uri (source)) {
+				update_user_in_source (source, e_source_get_property (source, "username"));
+				changed = TRUE;
+			}
+		}
+	}
+
+	if (changed)
+		e_source_list_sync (source_list, NULL);
+}
