@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -53,13 +53,13 @@ struct _proxyLoginClass {
 GType proxy_login_get_type (void);
 proxyLogin * proxy_login_new (void);
 static void proxy_login_cb (GtkDialog *dialog, gint state);
-static void proxy_login_add_new_store (char *uri, CamelStore *store, void *user_data);
+static void proxy_login_add_new_store (gchar *uri, CamelStore *store, gpointer user_data);
 static void proxy_login_setup_tree_view (void);
-void org_gnome_proxy_account_login (EPopup *ep, EPopupItem *p, void *data);
+void org_gnome_proxy_account_login (EPopup *ep, EPopupItem *p, gpointer data);
 proxyLogin* proxy_dialog_new (void);
-static void proxy_soap_login (char *email);
-char *parse_email_for_name (char *email);
+static void proxy_soap_login (gchar *email);
+gchar *parse_email_for_name (gchar *email);
 static void proxy_login_update_tree (void);
 static void proxy_login_tree_view_changed_cb(GtkDialog *dialog);
 void org_gnome_create_proxy_login_option(EPlugin *ep, EMPopupTargetFolder *t);
-static int proxy_get_password (EAccount *account, char **user_name, char **password);
+static gint proxy_get_password (EAccount *account, gchar **user_name, gchar **password);
