@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -68,7 +68,7 @@
 #include "evolution-listener.h"
 #include "evolution-shell-component-utils.h"
 
-static void set_line_status_complete(EvolutionListener *el, void *data);
+static void set_line_status_complete(EvolutionListener *el, gpointer data);
 
 #define PARENT_TYPE bonobo_object_get_type ()
 static BonoboObjectClass *parent_class = NULL;
@@ -76,7 +76,7 @@ static gboolean session_started = FALSE;
 
 struct _EShellPrivate {
 	/* IID for registering the object on OAF.  */
-	char *iid;
+	gchar *iid;
 
 	GList *windows;
 
@@ -85,11 +85,11 @@ struct _EShellPrivate {
 
 	/* Names for the types of the folders that have maybe crashed.  */
 	/* FIXME TODO */
-	GList *crash_type_names; /* char * */
+	GList *crash_type_names; /* gchar * */
 
 	/* Line status and controllers  */
 	EShellLineStatus line_status;
-	int line_status_pending;
+	gint line_status_pending;
 	EShellLineStatus line_status_working;
 	EvolutionListener *line_status_listener;
 
@@ -105,22 +105,21 @@ struct _EShellPrivate {
 	/* Whether the shell is succesfully initialized.  This is needed during
 	   the start-up sequence, to avoid CORBA calls to do make wrong things
 	   to happen while the shell is initializing.  */
-	unsigned int is_initialized : 1;
+	guint is_initialized : 1;
 
 	/* Wether the shell is working in "interactive" mode or not.
 	   (Currently, it's interactive IIF there is at least one active
 	   view.)  */
-	unsigned int is_interactive : 1;
+	guint is_interactive : 1;
 
 	/* Whether quit has been requested, and the shell is now waiting for
 	   permissions from all the components to quit.  */
-	unsigned int preparing_to_quit : 1;
+	guint preparing_to_quit : 1;
 
 	/* Whether we are recovering from a crash in the previous session. */
-	unsigned int crash_recovery : 1;
+	guint crash_recovery : 1;
 };
 
-
 /* Signals.  */
 
 enum {
@@ -132,7 +131,6 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-
 /* Utility functions.  */
 
 static gboolean
@@ -150,7 +148,6 @@ get_config_start_offline (void)
 	return value;
 }
 
-
 /* Interactivity handling.  */
 
 static void
@@ -160,7 +157,7 @@ set_interactive (EShell *shell,
 	GSList *component_list;
 	GSList *p;
 	GList *first_element;
-	int num_windows;
+	gint num_windows;
 	GtkWidget *view;
 
 	g_return_if_fail (E_IS_SHELL (shell));
@@ -200,7 +197,6 @@ set_interactive (EShell *shell,
 	}
 }
 
-
 /* CORBA interface implementation.  */
 
 static gboolean
@@ -260,8 +256,8 @@ impl_Shell_handleURI (PortableServer_Servant servant,
 {
 	EShell *shell = E_SHELL (bonobo_object_from_servant (servant));
 	EComponentInfo *component_info;
-	char *schema, *p;
-	int show = FALSE;
+	gchar *schema, *p;
+	gint show = FALSE;
 
 	schema = g_alloca(strlen(uri)+1);
 	strcpy(schema, uri);
@@ -269,7 +265,7 @@ impl_Shell_handleURI (PortableServer_Servant servant,
 	if (p)
 		*p = 0;
 
- 	component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_SCHEMA, schema);
+	component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_SCHEMA, schema);
 	if (component_info == NULL) {
 		show = TRUE;
 		component_info = e_component_registry_peek_info(shell->priv->component_registry, ECR_FIELD_ALIAS, schema);
@@ -346,10 +342,10 @@ impl_Shell_findComponent(PortableServer_Servant servant,
 
 /* EShellWindow handling and bookkeeping.  */
 
-static int
+static gint
 window_delete_event_cb (GtkWidget *widget,
 		      GdkEventAny *ev,
-		      void *data)
+		      gpointer data)
 {
 	EShell *shell;
 
@@ -360,7 +356,7 @@ window_delete_event_cb (GtkWidget *widget,
 }
 
 static gboolean
-notify_no_windows_left_idle_cb (void *data)
+notify_no_windows_left_idle_cb (gpointer data)
 {
 	EShell *shell;
 	EShellPrivate *priv;
@@ -381,11 +377,11 @@ notify_no_windows_left_idle_cb (void *data)
 }
 
 static void
-window_weak_notify (void *data,
+window_weak_notify (gpointer data,
 		    GObject *where_the_object_was)
 {
 	EShell *shell;
-	int num_windows;
+	gint num_windows;
 
 	shell = E_SHELL (data);
 
@@ -485,7 +481,6 @@ impl_finalize (GObject *object)
 	(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
-
 /* Initialization.  */
 
 static void
@@ -551,9 +546,9 @@ e_shell_init (EShell *shell)
 }
 
 static void
-detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
+detect_version (GConfClient *gconf, gint *major, gint *minor, gint *revision)
 {
-	char *val, *evolution_dir;
+	gchar *val, *evolution_dir;
 	struct stat st;
 
 	evolution_dir = g_build_filename (g_get_home_dir (), "evolution", NULL);
@@ -571,7 +566,7 @@ detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
 	} else {
 		xmlDocPtr config_doc;
 		xmlNodePtr source;
-		char *tmp;
+		gchar *tmp;
 
 		tmp = g_build_filename (evolution_dir, "config.xmldb", NULL);
 		config_doc = e_xml_parse_file (tmp);
@@ -600,11 +595,11 @@ detect_version (GConfClient *gconf, int *major, int *minor, int *revision)
 
 /* calls components to perform upgrade */
 static gboolean
-attempt_upgrade (EShell *shell, int major, int minor, int revision)
+attempt_upgrade (EShell *shell, gint major, gint minor, gint revision)
 {
 	GSList *component_infos, *p;
 	gboolean success;
-	int res;
+	gint res;
 
 	success = TRUE;
 
@@ -618,7 +613,7 @@ attempt_upgrade (EShell *shell, int major, int minor, int revision)
 		GNOME_Evolution_Component_upgradeFromVersion (info->iface, major, minor, revision, &ev);
 
 		if (BONOBO_EX (&ev)) {
-			char *exception_text;
+			gchar *exception_text;
 			CORBA_char *id = CORBA_exception_id(&ev);
 
 			if (strcmp (id, ex_CORBA_NO_IMPLEMENT) == 0) {
@@ -660,7 +655,7 @@ attempt_upgrade (EShell *shell, int major, int minor, int revision)
  **/
 EShellConstructResult
 e_shell_construct (EShell *shell,
-		   const char *iid,
+		   const gchar *iid,
 		   EShellStartupLineMode startup_line_mode)
 {
 	EShellPrivate *priv;
@@ -752,13 +747,13 @@ e_shell_new (EShellStartupLineMode startup_line_mode,
 	return new;
 }
 
-static int
-remove_dir(const char *root, const char *path)
+static gint
+remove_dir(const gchar *root, const gchar *path)
 {
 	GDir *dir;
-	const char *dname;
-	int res = -1;
-	char *new = NULL;
+	const gchar *dname;
+	gint res = -1;
+	gchar *new = NULL;
 	struct stat st;
 
 	dir = g_dir_open(path, 0, NULL);
@@ -804,12 +799,12 @@ gboolean
 e_shell_attempt_upgrade (EShell *shell)
 {
 	GConfClient *gconf_client;
-	int major = 0, minor = 0, revision = 0;
-	int lmajor, lminor, lrevision;
-	int cmajor, cminor, crevision;
-	char *version_string, *last_version = NULL;
-	int done_upgrade = FALSE;
-	char *oldpath;
+	gint major = 0, minor = 0, revision = 0;
+	gint lmajor, lminor, lrevision;
+	gint cmajor, cminor, crevision;
+	gchar *version_string, *last_version = NULL;
+	gint done_upgrade = FALSE;
+	gchar *oldpath;
 	struct stat st;
 	ESEvent *ese;
 
@@ -834,8 +829,8 @@ e_shell_attempt_upgrade (EShell *shell)
 		size = e_fsutils_usage(oldpath);
 		space = e_fsutils_avail(g_get_home_dir());
 		if (size != -1 && space != -1 && space < size) {
-			char *required = g_strdup_printf(_("%ld KB"), size);
-			char *have = g_strdup_printf(_("%ld KB"), space);
+			gchar *required = g_strdup_printf(_("%ld KB"), size);
+			gchar *have = g_strdup_printf(_("%ld KB"), space);
 
 			e_error_run(NULL, "shell:upgrade-nospace", required, have, NULL);
 			g_free(required);
@@ -855,7 +850,7 @@ e_shell_attempt_upgrade (EShell *shell)
 check_old:
 	/* if the last upgraded version was old, check for stuff to remove */
 	if (done_upgrade
-	    || 	(last_version = gconf_client_get_string (gconf_client, "/apps/evolution/last_version", NULL)) == NULL
+	    ||	(last_version = gconf_client_get_string (gconf_client, "/apps/evolution/last_version", NULL)) == NULL
 	    ||  sscanf(last_version, "%d.%d.%d", &lmajor, &lminor, &lrevision) != 3) {
 		lmajor = major;
 		lminor = minor;
@@ -866,7 +861,7 @@ check_old:
 	if (lmajor == 1 && lminor < 5
 	    && g_stat(oldpath, &st) == 0
 	    && S_ISDIR(st.st_mode)) {
-		int res;
+		gint res;
 
 		last_version = g_strdup_printf("%d.%d.%d", lmajor, lminor, lrevision);
 		res = e_error_run(NULL, "shell:upgrade-remove-1-4", last_version, NULL);
@@ -927,7 +922,7 @@ check_old:
  **/
 EShellWindow *
 e_shell_create_window (EShell *shell,
-		       const char *component_id,
+		       const gchar *component_id,
 		       EShellWindow *template_window)
 {
 	EShellWindow *window;
@@ -996,7 +991,6 @@ e_shell_peek_uri_schema_registry (EShell *shell)
 }
 #endif
 
-
 /**
  * e_shell_peek_component_registry:
  * @shell:
@@ -1013,7 +1007,6 @@ e_shell_peek_component_registry (EShell *shell)
 	return shell->priv->component_registry;
 }
 
-
 /**
  * e_shell_save_settings:
  * @shell:
@@ -1030,7 +1023,7 @@ e_shell_save_settings (EShell *shell)
 	GConfClient *client;
 	gboolean is_offline;
 
-	is_offline = ( e_shell_get_line_status (shell) == E_SHELL_LINE_STATUS_OFFLINE || e_shell_get_line_status (shell) == E_SHELL_LINE_STATUS_FORCED_OFFLINE);
+	is_offline = ( e_shell_get_line_status (shell) == E_SHELL_LINE_STATUS_OFFLINE );
 
 	client = gconf_client_get_default ();
 	gconf_client_set_bool (client, "/apps/evolution/shell/start_offline", is_offline, NULL);
@@ -1084,7 +1077,6 @@ e_shell_get_line_status (EShell *shell)
 	return shell->priv->line_status;
 }
 
-
 /* Offline/online handling.  */
 
 static void
@@ -1111,7 +1103,7 @@ set_line_status_finished(EShell *shell)
 }
 
 static void
-set_line_status_complete(EvolutionListener *el, void *data)
+set_line_status_complete(EvolutionListener *el, gpointer data)
 {
 	EShell *shell = data;
 	EShellPrivate *priv = shell->priv;
@@ -1132,20 +1124,20 @@ e_shell_set_line_status (EShell *shell,
 	GSList *p;
 	CORBA_Environment ev;
 	GConfClient *client;
-	gboolean status;
+	gboolean is_online;
 	gboolean forced = FALSE;
 
 	priv = shell->priv;
 
 	if (shell_state == GNOME_Evolution_FORCED_OFFLINE || shell_state == GNOME_Evolution_USER_OFFLINE) {
-		status = FALSE;
+		is_online = FALSE;
 		if (shell_state == GNOME_Evolution_FORCED_OFFLINE)
 			forced = TRUE;
 	} else
-		status = TRUE;
+		is_online = TRUE;
 
-	if ((status && priv->line_status == E_SHELL_LINE_STATUS_ONLINE)
-	    || (!status && priv->line_status == E_SHELL_LINE_STATUS_OFFLINE && !forced))
+	if ((is_online && priv->line_status == E_SHELL_LINE_STATUS_ONLINE)
+	    || (!is_online && priv->line_status == E_SHELL_LINE_STATUS_OFFLINE && !forced))
 		return;
 
 	/* we use 'going offline' to mean 'changing status' now */
@@ -1153,10 +1145,11 @@ e_shell_set_line_status (EShell *shell,
 	g_signal_emit (shell, signals[LINE_STATUS_CHANGED], 0, priv->line_status);
 
 	client = gconf_client_get_default ();
-	gconf_client_set_bool (client, "/apps/evolution/shell/start_offline", !status, NULL);
+	if (!forced)
+		gconf_client_set_bool (client, "/apps/evolution/shell/start_offline", !is_online, NULL);
 	g_object_unref (client);
 
-	priv->line_status_working = status?E_SHELL_LINE_STATUS_ONLINE: forced?E_SHELL_LINE_STATUS_FORCED_OFFLINE:E_SHELL_LINE_STATUS_OFFLINE;
+	priv->line_status_working = is_online ? E_SHELL_LINE_STATUS_ONLINE: forced?E_SHELL_LINE_STATUS_FORCED_OFFLINE:E_SHELL_LINE_STATUS_OFFLINE;
 	/* we start at 2: setLineStatus could recursively call back, we therefore
 	   `need to not complete till we're really complete */
 	priv->line_status_pending += 2;
@@ -1221,10 +1214,9 @@ e_shell_send_receive (EShell *shell)
 	}
 }
 
-
 void
 e_shell_show_settings (EShell *shell,
-		       const char *type,
+		       const gchar *type,
 		       EShellWindow *shell_window)
 {
 	EShellPrivate *priv;
@@ -1251,8 +1243,7 @@ e_shell_show_settings (EShell *shell,
 	gtk_widget_show (priv->settings_dialog.widget);
 }
 
-
-const char *
+const gchar *
 e_shell_construct_result_to_string (EShellConstructResult result)
 {
 	switch (result) {
