@@ -44,7 +44,6 @@ static const gint e_calendar_item_days_in_month[12] = {
   e_calendar_item_days_in_month[month] + (((month) == 1 \
   && ((year) % 4 == 0 && ((year) % 100 != 0 || (year) % 400 == 0))) ? 1 : 0)
 
-
 static void e_calendar_item_dispose	(GObject	 *object);
 static void e_calendar_item_get_property(GObject	 *object,
 					 guint		  property_id,
@@ -139,7 +138,8 @@ static void e_calendar_item_get_day_style	(ECalendarItem	*calitem,
 						 GdkColor      **bg_color,
 						 GdkColor      **fg_color,
 						 GdkColor      **box_color,
-						 gboolean	*bold);
+						 gboolean	*bold,
+						 gboolean	*italic);
 static void e_calendar_item_check_selection_end	(ECalendarItem	*calitem,
 						 gint		 start_month,
 						 gint		 start_day,
@@ -226,12 +226,10 @@ enum {
   LAST_SIGNAL
 };
 
-
 static guint e_calendar_item_signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (ECalendarItem, e_calendar_item, GNOME_TYPE_CANVAS_ITEM)
 
-
 static void
 e_calendar_item_class_init (ECalendarItemClass *class)
 {
@@ -525,7 +523,6 @@ e_calendar_item_class_init (ECalendarItemClass *class)
 	e_calendar_item_a11y_init ();
 }
 
-
 static void
 e_calendar_item_init (ECalendarItem *calitem)
 {
@@ -581,7 +578,6 @@ e_calendar_item_init (ECalendarItem *calitem)
 	calitem->signal_emission_idle_id = 0;
 }
 
-
 static void
 e_calendar_item_dispose		(GObject *object)
 {
@@ -618,7 +614,6 @@ e_calendar_item_dispose		(GObject *object)
 	G_OBJECT_CLASS (e_calendar_item_parent_class)->dispose (object);
 }
 
-
 static void
 e_calendar_item_get_property (GObject *object,
                               guint property_id,
@@ -700,7 +695,6 @@ e_calendar_item_get_property (GObject *object,
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
-
 static void
 e_calendar_item_set_property (GObject *object,
                               guint property_id,
@@ -852,7 +846,6 @@ e_calendar_item_realize		(GnomeCanvasItem *item)
 	e_calendar_item_style_set (GTK_WIDGET(item->canvas), calitem);
 }
 
-
 static void
 e_calendar_item_unrealize	(GnomeCanvasItem *item)
 {
@@ -869,7 +862,6 @@ e_calendar_item_unrealize	(GnomeCanvasItem *item)
 		(* GNOME_CANVAS_ITEM_CLASS (e_calendar_item_parent_class)->unrealize) (item);
 }
 
-
 static void
 e_calendar_item_unmap		(GnomeCanvasItem *item)
 {
@@ -886,7 +878,6 @@ e_calendar_item_unmap		(GnomeCanvasItem *item)
 		(* GNOME_CANVAS_ITEM_CLASS (e_calendar_item_parent_class)->unmap) (item);
 }
 
-
 static void
 e_calendar_item_update		(GnomeCanvasItem *item,
 				 double		 *affine,
@@ -1017,7 +1008,6 @@ e_calendar_item_update		(GnomeCanvasItem *item,
 	pango_font_metrics_unref (font_metrics);
 }
 
-
 /*
  * DRAWING ROUTINES - functions to paint the canvas item.
  */
@@ -1067,7 +1057,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 	bg = style->bg[GTK_STATE_NORMAL];
 	cr = gdk_cairo_create (drawable);
 
-
 	/* Clear the entire background. */
 	cairo_save (cr);
 	gdk_cairo_set_source_color (cr, &base);
@@ -1110,7 +1099,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 				  - xthickness * 2,
 				  bar_height);
 
-
 		for (col = 0; col < calitem->cols; col++) {
 			if (col != 0) {
 				col_x = calitem->x1 + calitem->x_offset
@@ -1125,7 +1113,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 						 col_x - 1 - x);
 			}
 
-
 			e_calendar_item_draw_month (calitem, drawable, x, y,
 						    width, height, row, col);
 		}
@@ -1137,7 +1124,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 	cairo_destroy (cr);
 }
 
-
 static void
 layout_set_day_text (ECalendarItem *calitem, PangoLayout *layout, gint day_index)
 {
@@ -1420,7 +1406,7 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	gint week_num, mon, days_from_week_start;
 	gint years[3], months[3], days_in_month[3];
 	gboolean today, selected, has_focus, drop_target = FALSE;
-	gboolean bold, draw_day, finished = FALSE;
+	gboolean bold, italic, draw_day, finished = FALSE;
 	gint today_year, today_month, today_mday, month_offset;
 	gchar buffer[9];
 	gint day_style = 0;
@@ -1579,6 +1565,9 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 				else
 					has_focus = FALSE;
 
+				bold = FALSE;
+				italic = FALSE;
+
 				if (calitem->style_callback)
 					(*calitem->style_callback)
 						(calitem,
@@ -1595,6 +1584,7 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 						 &fg_color,
 						 &box_color,
 						 &bold,
+						 &italic,
 						 calitem->style_callback_data);
 				else
 					e_calendar_item_get_day_style
@@ -1611,7 +1601,8 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 						 &bg_color,
 						 &fg_color,
 						 &box_color,
-						 &bold);
+						 &bold,
+						 &italic);
 
 				/* Draw the background, if set. */
 				if (bg_color) {
@@ -1664,6 +1655,13 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 				} else {
 					pango_font_description_set_weight (font_desc, PANGO_WEIGHT_NORMAL);
 				}
+
+				if (italic) {
+					pango_font_description_set_style (font_desc, PANGO_STYLE_ITALIC);
+				} else {
+					pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
+				}
+
 				pango_layout_set_font_description (layout, font_desc);
 				pango_layout_set_text (layout, buffer, num_chars);
 				cairo_translate (cr, day_x, day_y);
@@ -1696,8 +1694,9 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 			break;
 	}
 
-	/* Reset pango weight */
+	/* Reset pango weight and style */
 	pango_font_description_set_weight (font_desc, PANGO_WEIGHT_NORMAL);
+	pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
 
 	/* Reset the foreground color. */
 	gdk_gc_set_foreground (fg_gc, &style->fg[GTK_STATE_NORMAL]);
@@ -1750,8 +1749,6 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
 	return week_num + 1;
 }
 
-
-
 /* This is supposed to return the nearest item the the point and the distance.
    Since we are the only item we just return ourself and 0 for the distance.
    This is needed so that we get button/motion events. */
@@ -1964,7 +1961,6 @@ e_calendar_item_recalc_sizes		(ECalendarItem *calitem)
 						  pango_context_get_language (pango_context));
 	layout = pango_layout_new (pango_context);
 
-
 	char_height =
 		PANGO_PIXELS (pango_font_metrics_get_ascent (font_metrics)) +
 		PANGO_PIXELS (pango_font_metrics_get_descent (font_metrics));
@@ -2038,7 +2034,6 @@ e_calendar_item_recalc_sizes		(ECalendarItem *calitem)
 	pango_font_metrics_unref (font_metrics);
 }
 
-
 static void
 e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 					 gint		 year,
@@ -2053,7 +2048,8 @@ e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 					 GdkColor      **bg_color,
 					 GdkColor      **fg_color,
 					 GdkColor      **box_color,
-					 gboolean	*bold)
+					 gboolean	*bold,
+					 gboolean	*italic)
 {
 	GtkWidget *widget;
 	GtkStyle *style;
@@ -2064,10 +2060,9 @@ e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 	*bg_color = NULL;
 	*fg_color = NULL;
 	*box_color = NULL;
-	*bold = FALSE;
 
-	if (day_style == 1)
-		*bold = TRUE;
+	*bold = (day_style & E_CALENDAR_ITEM_MARK_BOLD) == E_CALENDAR_ITEM_MARK_BOLD;
+	*italic = (day_style & E_CALENDAR_ITEM_MARK_ITALIC) == E_CALENDAR_ITEM_MARK_ITALIC;
 
 	if (today)
 		*box_color = &calitem->colors[E_CALENDAR_ITEM_COLOR_TODAY_BOX];
@@ -2086,8 +2081,6 @@ e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 	}
 }
 
-
-
 static gboolean
 e_calendar_item_button_press	(ECalendarItem	*calitem,
 				 GdkEvent	*event)
@@ -2178,7 +2171,6 @@ e_calendar_item_button_release	(ECalendarItem	*calitem,
 	return FALSE;
 }
 
-
 static gboolean
 e_calendar_item_motion		(ECalendarItem	*calitem,
 				 GdkEvent	*event)
@@ -2258,7 +2250,6 @@ e_calendar_item_motion		(ECalendarItem	*calitem,
 		e_calendar_item_round_down_selection (calitem, &start_month,
 						      &start_day);
 
-
 	/* Check we don't go over the maximum number of days to select. */
 	if (calitem->selection_dragging_end) {
 		e_calendar_item_check_selection_end (calitem,
@@ -2290,7 +2281,6 @@ e_calendar_item_motion		(ECalendarItem	*calitem,
 	return TRUE;
 }
 
-
 static void
 e_calendar_item_check_selection_end	(ECalendarItem	*calitem,
 					 gint		 start_month,
@@ -2331,7 +2321,6 @@ e_calendar_item_check_selection_end	(ECalendarItem	*calitem,
 	}
 }
 
-
 static void
 e_calendar_item_check_selection_start	(ECalendarItem	*calitem,
 					 gint		*start_month,
@@ -2370,7 +2359,6 @@ e_calendar_item_check_selection_start	(ECalendarItem	*calitem,
 	}
 }
 
-
 /* Converts a position within the item to a month & day.
    The month returned is 0 for the top-left month displayed.
    If the position is over the month heading -1 is returned for the day.
@@ -2515,7 +2503,6 @@ e_calendar_item_convert_position_to_day	(ECalendarItem	*calitem,
 	return TRUE;
 }
 
-
 static void
 e_calendar_item_get_month_info	(ECalendarItem	*calitem,
 				 gint		 row,
@@ -2554,7 +2541,6 @@ e_calendar_item_get_month_info	(ECalendarItem	*calitem,
 		*first_day_offset = first_day_of_month;
 }
 
-
 void
 e_calendar_item_get_first_month(ECalendarItem	*calitem,
 				gint		*year,
@@ -2564,7 +2550,6 @@ e_calendar_item_get_first_month(ECalendarItem	*calitem,
 	*month = calitem->month;
 }
 
-
 static void
 e_calendar_item_preserve_day_selection	(ECalendarItem	*calitem,
 					 gint            selected_day,
@@ -2696,7 +2681,6 @@ e_calendar_item_get_max_days_sel       (ECalendarItem	*calitem)
 	return calitem->max_days_selected;
 }
 
-
 /* Set the maximum number of days selectable */
 void
 e_calendar_item_set_max_days_sel       (ECalendarItem	*calitem,
@@ -2706,7 +2690,6 @@ e_calendar_item_set_max_days_sel       (ECalendarItem	*calitem,
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (calitem));
 }
 
-
 /* Get the maximum number of days before whole weeks are selected */
 gint
 e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem)
@@ -2714,7 +2697,6 @@ e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem)
 	return calitem->days_to_start_week_selection;
 }
 
-
 /* Set the maximum number of days before whole weeks are selected */
 void
 e_calendar_item_set_days_start_week_sel(ECalendarItem	*calitem,
@@ -2729,7 +2711,6 @@ e_calendar_item_get_display_popup      (ECalendarItem	*calitem)
 	return calitem->display_popup;
 }
 
-
 void
 e_calendar_item_set_display_popup      (ECalendarItem	*calitem,
 					gboolean        display)
@@ -2737,7 +2718,6 @@ e_calendar_item_set_display_popup      (ECalendarItem	*calitem,
 	calitem->display_popup = display;
 }
 
-
 /* This will make sure that the given year & month are valid, i.e. if month
    is < 0 or > 11 the year and month will be updated accordingly. */
 void
@@ -2756,7 +2736,6 @@ e_calendar_item_normalize_date	(ECalendarItem	*calitem,
 	}
 }
 
-
 /* Adds or subtracts days from the selection. It is used when we switch months
    and the selection extends past the end of a month but we want to keep the
    number of days selected the same. days should not be more than 30. */
@@ -2785,7 +2764,6 @@ e_calendar_item_add_days_to_selection	(ECalendarItem	*calitem,
 	}
 }
 
-
 /* Gets the range of dates actually shown. Months are 0 to 11.
    This also includes the last days of the previous month and the first days
    of the following month, which are normally shown in gray.
@@ -2816,7 +2794,6 @@ e_calendar_item_get_date_range	(ECalendarItem	*calitem,
 	}
 	*start_day = days_in_prev_month + 1 - first_day_offset;
 
-
 	/* Calculate the last day shown. This will be one of the greyed-out
 	   days after the last full month ends. */
 	e_calendar_item_get_month_info (calitem, calitem->rows - 1,
@@ -2831,7 +2808,6 @@ e_calendar_item_get_date_range	(ECalendarItem	*calitem,
 	return TRUE;
 }
 
-
 /* Simple way to mark days so they appear bold.
    A more flexible interface may be added later. */
 void
@@ -2848,13 +2824,14 @@ e_calendar_item_clear_marks	(ECalendarItem	*calitem)
 				     item->x2, item->y2);
 }
 
-
+/* add_day_style - whether bit-or with the actual style or change the style fully */
 void
 e_calendar_item_mark_day	(ECalendarItem	*calitem,
 				 gint		 year,
 				 gint		 month,
 				 gint		 day,
-				 guint8		 day_style)
+				 guint8		 day_style,
+				 gboolean        add_day_style)
 {
 	gint month_offset;
 
@@ -2865,12 +2842,11 @@ e_calendar_item_mark_day	(ECalendarItem	*calitem,
 	if (!calitem->styles)
 		calitem->styles = g_new0 (guint8, (calitem->rows * calitem->cols + 2) * 32);
 
-	calitem->styles[(month_offset + 1) * 32 + day] = day_style;
+	calitem->styles[(month_offset + 1) * 32 + day] = (add_day_style ? calitem->styles[(month_offset + 1) * 32 + day] : 0) | day_style;
 
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (calitem));
 }
 
-
 void
 e_calendar_item_mark_days	(ECalendarItem	*calitem,
 				 gint		 start_year,
@@ -2879,7 +2855,8 @@ e_calendar_item_mark_days	(ECalendarItem	*calitem,
 				 gint		 end_year,
 				 gint		 end_month,
 				 gint		 end_day,
-				 guint8		 day_style)
+				 guint8		 day_style,
+				 gboolean        add_day_style)
 {
 	gint month_offset, end_month_offset, day;
 
@@ -2920,7 +2897,7 @@ e_calendar_item_mark_days	(ECalendarItem	*calitem,
 #if 0
 		g_print ("Marking Month:%i Day:%i\n", month_offset, day);
 #endif
-		calitem->styles[(month_offset + 1) * 32 + day] = day_style;
+		calitem->styles[(month_offset + 1) * 32 + day] = (add_day_style ? calitem->styles[(month_offset + 1) * 32 + day] : 0) | day_style;
 
 		day++;
 		if (day == 32) {
@@ -2934,7 +2911,6 @@ e_calendar_item_mark_days	(ECalendarItem	*calitem,
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (calitem));
 }
 
-
 /* Rounds up the given day to the end of the week. */
 static void
 e_calendar_item_round_up_selection	(ECalendarItem	*calitem,
@@ -2968,7 +2944,6 @@ e_calendar_item_round_up_selection	(ECalendarItem	*calitem,
 	}
 }
 
-
 /* Rounds down the given day to the start of the week. */
 static void
 e_calendar_item_round_down_selection	(ECalendarItem	*calitem,
@@ -3007,7 +2982,6 @@ e_calendar_item_round_down_selection	(ECalendarItem	*calitem,
 	}
 }
 
-
 static gint
 e_calendar_item_get_inclusive_days	(ECalendarItem	*calitem,
 					 gint		 start_month_offset,
@@ -3039,7 +3013,6 @@ e_calendar_item_get_inclusive_days	(ECalendarItem	*calitem,
 	return days;
 }
 
-
 /* If the day is off the end of the month it is set to the last day of the
    month. */
 static void
@@ -3058,7 +3031,6 @@ e_calendar_item_ensure_valid_day	(ECalendarItem	*calitem,
 		*day = days_in_month;
 }
 
-
 gboolean
 e_calendar_item_get_selection		(ECalendarItem	*calitem,
 					 GDate		*start_date,
@@ -3089,7 +3061,6 @@ e_calendar_item_get_selection		(ECalendarItem	*calitem,
 	return TRUE;
 }
 
-
 static void
 e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
 					   GDate		*start_date,
@@ -3144,7 +3115,6 @@ e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
 		+ end_month - calitem->month;
 	new_end_day = end_day;
 
-
 	if (!calitem->selection_set
 	    || calitem->selection_start_month_offset != new_start_month_offset
 	    || calitem->selection_start_day != new_start_day
@@ -3295,7 +3265,6 @@ e_calendar_item_ensure_days_visible	(ECalendarItem	*calitem,
 	return need_update;
 }
 
-
 static void
 e_calendar_item_show_popup_menu		(ECalendarItem	*calitem,
 					 GdkEventButton	*event,
@@ -3354,7 +3323,6 @@ e_calendar_item_show_popup_menu		(ECalendarItem	*calitem,
 	gtk_widget_destroy (menu);
 }
 
-
 static void
 e_calendar_item_on_menu_item_activate	(GtkWidget	*menuitem,
 					 ECalendarItem	*calitem)
@@ -3370,7 +3338,6 @@ e_calendar_item_on_menu_item_activate	(GtkWidget	*menuitem,
 	e_calendar_item_set_first_month (calitem, year, month);
 }
 
-
 static void
 e_calendar_item_position_menu	(GtkMenu            *menu,
 				 gint               *x,
@@ -3395,7 +3362,6 @@ e_calendar_item_position_menu	(GtkMenu            *menu,
 	*y = CLAMP (*y, 0, screen_height - requisition.height);
 }
 
-
 /* Sets the function to call to get the colors to use for a particular day. */
 void
 e_calendar_item_set_style_callback	(ECalendarItem	*calitem,
@@ -3413,7 +3379,6 @@ e_calendar_item_set_style_callback	(ECalendarItem	*calitem,
 	calitem->style_callback_destroy = destroy;
 }
 
-
 static void
 e_calendar_item_date_range_changed	(ECalendarItem	*calitem)
 {
@@ -3423,7 +3388,6 @@ e_calendar_item_date_range_changed	(ECalendarItem	*calitem)
 	e_calendar_item_queue_signal_emission (calitem);
 }
 
-
 static void
 e_calendar_item_queue_signal_emission	(ECalendarItem	*calitem)
 {
@@ -3432,7 +3396,6 @@ e_calendar_item_queue_signal_emission	(ECalendarItem	*calitem)
 	}
 }
 
-
 static gboolean
 e_calendar_item_signal_emission_idle_cb	(gpointer data)
 {
@@ -3466,7 +3429,6 @@ e_calendar_item_signal_emission_idle_cb	(gpointer data)
 	return FALSE;
 }
 
-
 /* Sets a callback to use to get the current time. This is useful if the
    application needs to use its own timezone data rather than rely on the
    Unix timezone. */
