@@ -1,25 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-cell-checkbox.c: Checkbox cell renderer
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Miguel de Icaza <miguel@ximian.com>
+ *		Miguel de Icaza <miguel@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
+
 #include <config.h>
 
 #include <gdk/gdkkeysyms.h>
@@ -40,11 +41,11 @@ static GdkPixbuf *checks [2];
 
 static void
 ecc_print (ECellView *ecell_view, GtkPrintContext *context,
-	    int model_col, int view_col, int row,
+	    gint model_col, gint view_col, gint row,
 	    double width, double height)
 {
 	cairo_t *cr = gtk_print_context_get_cairo_context (context);
-	const int value = GPOINTER_TO_INT (
+	const gint value = GPOINTER_TO_INT (
 			  e_table_model_value_at (ecell_view->e_table_model, model_col, row));
 	cairo_save (cr);
 
